import algoliasearch from "algoliasearch";
import fs from "fs";
import path from "path";
import { parseMarkdown } from "./compile-terms";

const termsFiles = fs.readdirSync(`${__dirname}/terms`);

const terms = termsFiles.map((file) => {
  const term = parseMarkdown(`${__dirname}/terms/${file}`);
  const {
    labels,
    relatedTerms,
    usageInstructions,
    exampleUsage,
    businessContext,
    internalOnly,
    learnMore,
    learnMoreText,
  } = term.frontmatter;

  const termName = path.basename(file, path.extname(file));

  return {
    term: decodeURIComponent(termName),
    objectID: termName,
    definition: term.definition,
    labels,
    relatedTerms,
    usageInstructions,
    exampleUsage,
    businessContext,
    internalOnly,
    learnMore,
    learnMoreText,
  };
});

// Initialize Algolia client
const client = algoliasearch(
  process.env.ALGOLIA_APP_ID!,
  process.env.ALGOLIA_API_KEY!
);

const indexName =
  process.env.CONTEXT === "production" ? "apollopedia" : "apollopedia_staging";

// Initialize the index
const index = client.initIndex(indexName);

// Add or update records in the index
index
  .replaceAllObjects(terms)
  .then(({ objectIDs }) => {
    console.log(
      `Indexed ${objectIDs.length} terms to ${indexName} index in Algolia`
    );
  })
  .catch((error) => {
    console.error("Error indexing to Algolia:", error);
  });
